@@ -268,7 +268,7 @@ class ImageSubsetArray(object):
 
     @property
     def size(self):
-        return np.product(self.shape)
+        return np.prod(self.shape)
 
 
 class ImageSubsetLayerArtist(BaseImageLayerArtist):
