@@ -30,6 +30,7 @@ DENSITY_PROPERTIES = set(['dpi', 'stretch', 'density_contrast'])
 VISUAL_PROPERTIES = (CMAP_PROPERTIES | MARKER_PROPERTIES | DENSITY_PROPERTIES |
                      LINE_PROPERTIES | set(['color', 'alpha', 'zorder', 'visible']))
 
+LIMIT_PROPERTIES = set(['x_min', 'x_max', 'y_min', 'y_max'])
 DATA_PROPERTIES = set(['layer', 'x_att', 'y_att', 'cmap_mode', 'size_mode', 'density_map',
                        'xerr_att', 'yerr_att', 'xerr_visible', 'yerr_visible',
                        'vector_visible', 'vx_att', 'vy_att', 'vector_arrowhead', 'vector_mode',
@@ -230,7 +231,6 @@ class ScatterLayerArtist(MatplotlibLayerArtist):
                 self.plot_artist.set_data([], [])
                 self.scatter_artist.set_offsets(np.zeros((0, 2)))
             else:
-
                 full_sphere = getattr(self._viewer_state, 'using_full_sphere', False)
                 degrees = getattr(self._viewer_state, 'using_degrees', False)
                 if degrees:
@@ -238,6 +238,15 @@ class ScatterLayerArtist(MatplotlibLayerArtist):
                     if full_sphere:
                         y = np.radians(y)
 
+                # The full-sphere projections expect longitude angles in the range [-pi, pi]
+                # so we wrap angles to accommodate this
+                if full_sphere:
+                    x = np.mod(x + np.pi, 2 * np.pi) - np.pi
+                    if self._viewer_state.x_min > self._viewer_state.x_max:
+                        x = np.negative(x)
+                    if self._viewer_state.y_min > self._viewer_state.y_max:
+                        y = np.negative(y)
+
                 self.density_artist.set_label(None)
                 if self._use_plot_artist():
                     # In this case we use Matplotlib's plot function because it has much
@@ -520,7 +529,9 @@ class ScatterLayerArtist(MatplotlibLayerArtist):
         # of updated properties is up to date after this method has been called.
         changed = self.pop_changed_properties()
 
-        if force or len(changed & DATA_PROPERTIES) > 0:
+        full_sphere = getattr(self._viewer_state, 'using_full_sphere', False)
+        change_from_limits = full_sphere and len(changed & LIMIT_PROPERTIES) > 0
+        if force or change_from_limits or len(changed & DATA_PROPERTIES) > 0:
             self._update_data()
             force = True
 
